@@ -49,27 +49,34 @@ GET_DATA_DRIFT_DIAGNOSIS_URI = f"{API_VERSION_V2}/project/get_data_drift_diagnos
 GET_PROJECT_CONFIG = f"{API_VERSION_V2}/users/get_xai_config"
 AVAILABLE_TAGS_URI = f"{API_VERSION_V2}/project/get_all_available_tags_info"
 TAG_DATA_URI = f"{API_VERSION_V2}/project/tag_data"
+GET_AVAILABLE_TEXT_MODELS_URI = f"{API_VERSION_V2}/users/get_available_text_models"
+INITIALIZE_TEXT_MODEL_URI = f"{API_VERSION_V2}/users/initalize_text_model"
+GET_FEATURE_IMPORTANCE_URI = f"{API_VERSION_V2}/project/get_feature_importance"
 
 # Monitoring
 GENERATE_DASHBOARD_URI = f"{API_VERSION_V2}/dashboards/generate_dashboard"
 DASHBOARD_CONFIG_URI = f"{API_VERSION_V2}/dashboards/config"
 MODEL_PERFORMANCE_DASHBOARD_URI = (
-    f"{API_VERSION_V2}/dashboard/model_performance_dashboard"
+    f"{API_VERSION_V2}/dashboards/model_performance_dashboard"
 )
 DASHBOARD_LOGS_URI = f"{API_VERSION_V2}/dashboards/get_dashboard_logs"
 GET_DASHBOARD_URI = f"{API_VERSION_V2}/dashboards/get_dashboard"
 DOWNLOAD_DASHBOARD_LOGS_URI = f"{API_VERSION_V2}/dashboards/download_dashboard_logs"
+GET_DASHBOARD_SCORE_URI = f"{API_VERSION_V2}/dashboards/get_dashboard_score"
 
 # Auto ML
 MODEL_PARAMETERS_URI = f"{API_VERSION_V2}/users/get_xai_model_parameters"
 TRAIN_MODEL_URI = f"{API_VERSION_V2}/users/xai_config_update"
 GET_MODELS_URI = f"{API_VERSION_V2}/ai-models/get_all_models"
 UPDATE_ACTIVE_MODEL_URI = f"{API_VERSION_V2}/ai-models/update_active_model"
-UPDATE_ACTIVE_INFERENCE_MODEL_URI = f"{API_VERSION_V2}/ai-models/update_active_inference"
+UPDATE_ACTIVE_INFERENCE_MODEL_URI = (
+    f"{API_VERSION_V2}/ai-models/update_active_inference"
+)
 REMOVE_MODEL_URI = f"{API_VERSION_V2}/ai-models/remove_model"
 RUN_MODEL_ON_DATA_URI = f"{API_VERSION_V2}/ai-models/run_model_on_data"
 DOWNLOAD_TAG_DATA_URI = f"{API_VERSION_V2}/ai-models/download_tag_data"
 MODEL_SUMMARY_URI = f"{API_VERSION_V2}/project/get_model_perfermance"
+PROJECT_OVERVIEW_TEXT_URI = f"{API_VERSION_V2}/ai-models/project_overview"
 MODEL_SVG_URI = f"{API_VERSION_V2}/project/get_model_svg_plot"
 MODEL_INFERENCES_URI = f"{API_VERSION_V2}/ai-models/get_all_tags_for_models"
 
@@ -77,10 +84,13 @@ MODEL_INFERENCES_URI = f"{API_VERSION_V2}/ai-models/get_all_tags_for_models"
 GET_CASES_URI = f"{API_VERSION_V2}/ai-models/get_cases"
 SEARCH_CASE_URI = f"{API_VERSION_V2}/ai-models/search_case"
 CASE_INFO_URI = f"{API_VERSION_V2}/ai-models/get_case_info_components"
+CASE_INFO_TEXT_URI = f"{API_VERSION_V2}/ai-models/get_case_info_text"
 CASE_DTREE_URI = f"{API_VERSION_V2}/ai-models/get_case_dtree"
 DELETE_CASE_URI = f"{API_VERSION_V2}/project/delete_data_with_filter"
 CASE_LOGS_URI = f"{API_VERSION_V2}/ai-models/explainability_logs"
+CASE_LOGS_TEXT_URI = f"{API_VERSION_V2}/ai-models/explainability_logs_text"
 GET_VIEWED_CASE_URI = f"{API_VERSION_V2}/ai-models/get_viewed_case"
+GENERATE_TEXT_CASE_URI = f"{API_VERSION_V2}/ai-models/run_model_on_data_text"
 
 # Observations
 GET_OBSERVATIONS_URI = f"{API_VERSION_V2}/observations/get_observations"
@@ -102,6 +112,8 @@ DUPLICATE_MONITORS_URI = f"{API_VERSION_V2}/triggers/duplicate_monitors"
 EXECUTED_TRIGGER_URI = f"{API_VERSION_V2}/triggers/get_executed_triggers"
 GET_EXECUTED_TRIGGER_INFO = f"{API_VERSION_V2}/triggers/get_trigger_details"
 GET_LABELS_URI = f"{API_VERSION_V2}/triggers/get_label_classes"
+GET_TRIGGERS_DAYS_URI = f"{API_VERSION_V2}/triggers/get_alerts"
+GET_MONITORS_ALERTS = f"{API_VERSION_V2}/triggers/get_monitors_alerts"
 
 # Synthetic AI
 AVAILABLE_SYNTHETIC_CUSTOM_SERVERS_URI = f"{API_VERSION_V2}/synthetics/custom_servers"
@@ -147,5 +159,14 @@ DELETE_DATA_CONNECTORS = f"{API_VERSION_V2}/linkservices/delete"
 UPLOAD_FILE_DATA_CONNECTORS = f"{API_VERSION_V2}/project/uploadfile_with_linkservices"
 DROPBOX_OAUTH = f"{API_VERSION_V2}/linkservices/dropbox_auth"
 
-#Credits
+# Credits
 COMPUTE_CREDIT_URI = f"{API_VERSION_V2}/plans/compute_credit"
+
+# evals
+TABULAR_ML = f"{API_VERSION_V2}/evals/evals-tabular"
+TABULAR_DL = f"{API_VERSION_V2}/evals/evals-tabular"
+IMAGE_DL = f"{API_VERSION_V2}/evals/"
+
+
+# Agents 
+EXPLAINABILITY_SUMMARY = f"{API_VERSION_V2}/agents/explainability_summary"
\ No newline at end of file
